@@ -1,11 +1,11 @@
 #' @describeIn tbl_graph Method for adjacency lists and lists of node and edge tables
 #' @export
-as_tbl_graph.list <- function(x, directed = TRUE, ...) {
+as_tbl_graph.list <- function(x, directed = TRUE, node_key = 'name', ...) {
   graph <- switch(
     guess_list_type(x),
     adjacency = as_graph_adj_list(x, directed = directed),
-    node_edge = as_graph_node_edge(x, directed = directed),
-    unknown = stop("Unknown list format", call. = FALSE)
+    node_edge = as_graph_node_edge(x, directed = directed, node_key = node_key),
+    unknown = cli::cli_abort("Unknown list format")
   )
   as_tbl_graph(graph)
 }
@@ -61,7 +61,7 @@ as_graph_adj_list <- function(x, directed) {
 
 #' @importFrom igraph graph_from_edgelist vertex_attr<- add_vertices gorder
 #' @importFrom tibble tibble
-as_graph_node_edge <- function(x, directed) {
+as_graph_node_edge <- function(x, directed, node_key = 'name') {
   nodes <- x[[which(names(x) %in% c('nodes', 'vertices'))]]
   edges <- x[[which(names(x) %in% c('edges', 'links'))]]
   if (is.null(edges)) {
@@ -71,20 +71,28 @@ as_graph_node_edge <- function(x, directed) {
   if (length(from_ind) == 0) from_ind <- 1
   to_ind <- which(names(edges) == 'to')
   if (length(to_ind) == 0) to_ind <- 2
-  name_ind <- which(names(nodes) == 'name')
-  if (length(name_ind) == 0) name_ind <- 1
   edges <- edges[, c(from_ind, to_ind, seq_along(edges)[-c(from_ind, to_ind)]), drop = FALSE]
-  if (is.character(edges[, 1])) {
-    edges[, 1] <- match(edges[, 1], nodes[, name_ind])
-  }
-  if (is.character(edges[, 2])) {
-    edges[, 2] <- match(edges[, 2], nodes[, name_ind])
+  if (!is.null(nodes)) {
+    if (is.na(node_key)) {
+      name_ind <- 1L
+    } else {
+      name_ind <- which(names(nodes) == node_key)
+      if (length(name_ind) == 0) name_ind <- 1
+    }
+    if (is.character(edges[[1]])) {
+      edges[, 1] <- match(edges[[1]], nodes[[name_ind]])
+    }
+    if (is.character(edges[[2]])) {
+      edges[, 2] <- match(edges[[2]], nodes[[name_ind]])
+    }
   }
   gr <- graph_from_edgelist(as.matrix(edges[, 1:2]), directed = directed)
   edge_attr(gr) <- as.list(edges[, -c(1:2), drop = FALSE])
-  if (gorder(gr) != nrow(nodes)) {
-    gr <- add_vertices(gr, nrow(nodes) - gorder(gr))
+  if (!is.null(nodes)) {
+    if (gorder(gr) != nrow(nodes)) {
+      gr <- add_vertices(gr, nrow(nodes) - gorder(gr))
+    }
+    vertex_attr(gr) <- as.list(nodes)
   }
-  vertex_attr(gr) <- as.list(nodes)
   gr
 }
